import java.io.IOException;
import java.net.Socket;
import java.net.UnknownHostException;

/**
 * Starte einen Chatclient.
 * 
 * @author Bernd Gramlich. 
 * @version 2014-12-09
 */
public class ChatClient
{
    private Socket meinSocket = null;
    
    /**
     * Konstruktor.
     * Der Konstruktor ist private, da er nicht benutzt werden soll.
     * Verbinde Dich an den angegebenen Port des angegebenen Servers.
     */
    private ChatClient (String serverName, int portNr)
    {
        try 
        {
            meinSocket = new Socket (serverName, portNr);
        } 
        catch (UnknownHostException e) 
        {
            System.err.println ("Finde " + serverName + " nicht.");
        } 
        catch (IOException e) 
        {
            System.err.println ("Keine Verbindung zu " + serverName + ".");
        }
    }
    
    /**
     * Nenne meinen Socket.
     */
    public Socket gibSocket ()
    {
        return meinSocket;
    }
    
    /**
     * Starte einen Client. Verbinde Dich dabei an den
     * angegebenen Port des angegebenen Servers.
     */
    public static void starteClient (String serverName, int portNr)
    {
        ChatClient client = new ChatClient (serverName, portNr);
        Socket clientSocket;
        
        if (client != null)
        {
            clientSocket = client.gibSocket ();
            
            if (clientSocket != null)
            {  
                /*
                 * Starte den ClientEmpfangsProzess in einem neuen Thread,
                 * den ClientSendeProzess jedoch im laufenden Thread, damit er
                 * Zugriff auf die Standardeingabe hat.
                 */
                new Thread (new ClientEmpfangsProzess (clientSocket)).start ();        
                new ClientSendeProzess (clientSocket).run ();
            }
        }
    }
}
